@@ -9,14 +9,18 @@ import sys
 try:
     import osso
     maemo = True
-    logging.warning("Maemo detected")
+    #logging.warning("Maemo detected")
 except:
     maemo = False
-    logging.info("Not Maemo")
+    #logging.info("Not Maemo")
 
 if __name__ == "__main__":
     app = QApplication (sys.argv)
 
+    #app.setOrganizationName('mmlado')
+    app.setApplicationName('PeQersi')
+    app.setApplicationVersion('0.0.0')
+
     main = Main(maemo = maemo)
     main.show()
 
